@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# Application Name - Health Check V0.5.1-4
+# Application Name - Health Check V0.5.1-5
 # Date 17 February 2010
 # Author - Greg Roberts (Noobmonkey @ Maemo Talk)
 # Contact - Me@Greg-roberts.com
@@ -45,7 +45,7 @@ import hildon
 import dbus.glib
 
 #For bluetooth - apt-get install python-bluetooth
-import bluetooth
+#import bluetooth
 
 # osso_c = osso.Context("healthcheck", "666", True)
 
@@ -112,9 +112,9 @@ class Ui_MainWindow(object):
         
         # Setup and draw the button
         self.pushButton_hw = QtGui.QPushButton(self.tab)
-        self.pushButton_hw.setGeometry(QtCore.QRect(580, 310, 211, 51))
+        self.pushButton_hw.setGeometry(QtCore.QRect(0, 310, 800, 51))
         self.pushButton_hw.setObjectName("pushButton_hw")
-        self.pushButton_hw.setText("Update")
+        self.pushButton_hw.setText("Update All")
         # Tell the button what to do when it is clicked. In this case i want it to run the updateTab1 function below
         QtCore.QObject.connect(self.pushButton_hw, QtCore.SIGNAL('clicked()'), self.updateTab1)
                 
@@ -135,9 +135,9 @@ class Ui_MainWindow(object):
 
         # Setup and draw the button
         self.pushButton_com = QtGui.QPushButton(self.tab_2)
-        self.pushButton_com.setGeometry(QtCore.QRect(580, 310, 211, 51))
+        self.pushButton_com.setGeometry(QtCore.QRect(0, 310, 800, 51))
         self.pushButton_com.setObjectName("pushButton_com")
-        self.pushButton_com.setText("Update")
+        self.pushButton_com.setText("Update All")
         # Tell the button what to do when it is clicked. In this case i want it to run the updateTab1 function below
         QtCore.QObject.connect(self.pushButton_com, QtCore.SIGNAL('clicked()'), self.updateTab2)
 
@@ -217,7 +217,7 @@ class Ui_MainWindow(object):
         # box of some sort
         self.textBrowser = QtGui.QTextBrowser(self.tab_5)
         self.textBrowser.setGeometry(QtCore.QRect(0, 10, 781, 301))
-        self.textBrowser.setText (" Health Check V 0.5.1-4 \n Greg Roberts (Maemo.org - Noobmonkey) \n me@greg-roberts.com \n \n For Bugs and Feature requests: \n http://talk.maemo.org/showthread.php?p=541457")
+        self.textBrowser.setText (" Health Check V 0.5.1-5 \n Greg Roberts (Maemo.org - Noobmonkey) \n me@greg-roberts.com \n \n For Bugs and Feature requests: \n http://talk.maemo.org/showthread.php?p=541457")
         # Make the font small!!!
         font = QtGui.QFont()
         font.setPointSize(20)
@@ -242,7 +242,7 @@ class Ui_MainWindow(object):
         # Set which tab you want showing on program load
         self.tabWidget.setCurrentIndex(0)
         QtCore.QMetaObject.connectSlotsByName(MainWindow)
-        Thread(target=self.updateTab1()).start()
+        #Thread(target=self.updateTab1()).start()
         
 
     
@@ -420,11 +420,12 @@ class Ui_MainWindow(object):
 
         b = None
         b = os.popen('run-standalone.sh dbus-send --system --type=signal /com/nokia/mce/signal com.nokia.mce.signal.sig_device_orientation_ind').read()
+        
         coords = str(coords)
         jaccel = str(coords) + str(b)
         
         self.listWidget.addItem("Accelerometer \t\t" + jaccel)
-        
+        b.close()
         #Bluetooth
         #print "performing inquiry..."
         #nearby_devices = bluetooth.discover_devices(lookup_names = True)
@@ -439,26 +440,40 @@ class Ui_MainWindow(object):
         # the co-ords need to be pulled out and split for easy reading
         # Close down the co-ord file once used (Only displaying static info, not updating yet)
         bb = 'run-standalone.sh dbus-send --print-reply --system --dest=com.nokia.mce /com/nokia/mce/request com.nokia.mce.request.req_vibrator_pattern_activate string:' + "\'PatternTouchscreen\'"
-        print bb
         b = os.popen(bb)
+        b.close()
+        bb = 'run-standalone.sh dbus-send --print-reply --system --dest=com.nokia.mce /com/nokia/mce/request com.nokia.mce.request.req_vibrator_pattern_activate string:' + "\'PatternTouchscreen\'"
         b = os.popen(bb)
+        b.close()
+        bb = 'run-standalone.sh dbus-send --print-reply --system --dest=com.nokia.mce /com/nokia/mce/request com.nokia.mce.request.req_vibrator_pattern_activate string:' + "\'PatternTouchscreen\'"
         b = os.popen(bb)
+        b.close()
+        bb = 'run-standalone.sh dbus-send --print-reply --system --dest=com.nokia.mce /com/nokia/mce/request com.nokia.mce.request.req_vibrator_pattern_activate string:' + "\'PatternTouchscreen\'"
         b = os.popen(bb)
+        b.close()
+        bb = 'run-standalone.sh dbus-send --print-reply --system --dest=com.nokia.mce /com/nokia/mce/request com.nokia.mce.request.req_vibrator_pattern_activate string:' + "\'PatternTouchscreen\'"
         b = os.popen(bb)
+        b.close()
+        bb = 'run-standalone.sh dbus-send --print-reply --system --dest=com.nokia.mce /com/nokia/mce/request com.nokia.mce.request.req_vibrator_pattern_activate string:' + "\'PatternTouchscreen\'"
         b = os.popen(bb)
+        b.close()
+        bb = 'run-standalone.sh dbus-send --print-reply --system --dest=com.nokia.mce /com/nokia/mce/request com.nokia.mce.request.req_vibrator_pattern_activate string:' + "\'PatternTouchscreen\'"
         b = os.popen(bb)
+        b.close()
+        bb = 'run-standalone.sh dbus-send --print-reply --system --dest=com.nokia.mce /com/nokia/mce/request com.nokia.mce.request.req_vibrator_pattern_activate string:' + "\'PatternTouchscreen\'"
         b = os.popen(bb)
+        b.close()
+        bb = 'run-standalone.sh dbus-send --print-reply --system --dest=com.nokia.mce /com/nokia/mce/request com.nokia.mce.request.req_vibrator_pattern_activate string:' + "\'PatternTouchscreen\'"
         b = os.popen(bb)
+        b.close()
+        bb = 'run-standalone.sh dbus-send --print-reply --system --dest=com.nokia.mce /com/nokia/mce/request com.nokia.mce.request.req_vibrator_pattern_activate string:' + "\'PatternTouchscreen\'"
         b = os.popen(bb)
-        b = os.popen(bb)
-        b = os.popen(bb)
-        b = os.popen(bb)
-        b = os.popen(bb)
-        b = os.popen(bb)
-        b = os.popen(bb)
-        bb= 'dbus-send --print-reply --system --dest=com.nokia.mce /com/nokia/mce/request com.nokia.mce.request.req_vibrator_pattern_deactiv ate string:' + "\'PatternIncomingCall\'"
-        b = os.popen(bb)
+        b.close()
         
+        b.close()
+        bb= 'dbus-send --print-reply --system --dest=com.nokia.mce /com/nokia/mce/request com.nokia.mce.request.req_vibrator_pattern_deactivate string:' + "\'PatternIncomingCall\'"
+        b = os.popen(bb)
+        b.close()
         
        
         
@@ -511,7 +526,7 @@ class Ui_MainWindow(object):
         self.pushButton_hw.setText(".......")
         Thread(target=self.updateBatt()).start()
         self.pushButton_hw.setText("........")
-        self.pushButton_hw.setText("Update")
+        self.pushButton_hw.setText("Update All")
         self.pushButton_hw.setEnabled(True)
         self.listWidget.sortItems()
 
@@ -522,7 +537,7 @@ class Ui_MainWindow(object):
         Thread(target=self.updateGPS()).start()
         self.pushButton_com.setText(".....")
         Thread(target=self.Cellular()).start()
-        self.pushButton_com.setText("Update")
+        self.pushButton_com.setText("Update All")
         self.pushButton_com.setEnabled(True)
         self.listWidget2.sortItems()
 
@@ -542,7 +557,7 @@ class Ui_MainWindow(object):
         
     # This is the start of the QT Designer translation function - not using the translation function, but left it in, to show it is part of the class   
     def retranslateUi(self, MainWindow):
-        MainWindow.setWindowTitle(QtGui.QApplication.translate("MainWindow", "Health Check 0.5.1-4", None, QtGui.QApplication.UnicodeUTF8))
+        MainWindow.setWindowTitle(QtGui.QApplication.translate("MainWindow", "Health Check 0.5.1-5", None, QtGui.QApplication.UnicodeUTF8))
         self.tabWidget.setTabText(self.tabWidget.indexOf(self.tab), QtGui.QApplication.translate("MainWindow", "System", None, QtGui.QApplication.UnicodeUTF8))
         self.tabWidget.setTabText(self.tabWidget.indexOf(self.tab_2), QtGui.QApplication.translate("MainWindow", "Comms", None, QtGui.QApplication.UnicodeUTF8))
         self.tabWidget.setTabText(self.tabWidget.indexOf(self.tab_3), QtGui.QApplication.translate("MainWindow", "Camera", None, QtGui.QApplication.UnicodeUTF8))
